# Hello::Printer provide utils for various print operations
package Hello::Printer;

use strict;
use warnings;

# hello() prints hello
sub hello {
	...
}

# wow() prints wow
sub wow {
	...
}

sub nocomment {
	my $foo = shift;
}

sub foo{
	my $self =shift;
}

1;
